@@ -218,17 +218,6 @@ class OvsHost(linux.LinuxDevice):
                     %(ovs_get_container_port(bridge_name, name = name),
                         kwargs["vlan"]))
 
-    def __add_vm3 (self, bridge_name, name, type = "vm", **kwargs):
-        '''
-        '''
-        p = {"name": "to_%s" %(name),
-                "type": "dpdkvhostuserclient",
-                "options:vhost-server-path": kwargs.get("path", None)}
-        self.add_port(bridge_name, **p)
-        if kwargs.get("start_cmd", None):
-            # start the vm if it doesn't auto start
-            self.cmd(kwargs["start_cmd"])
-
     def __add_vm (self, bridge_name, **kwargs):
         '''
         # The following parameter are mandatory:
@@ -249,7 +238,8 @@ class OvsHost(linux.LinuxDevice):
                 "/tmp/%s.pid" %(kwargs["-name"]))
         kwargs["-enable-kvm"] = kwargs.get("-enable-kvm", "")
         kwargs["-object"] = kwargs.get("-object",
-        "memory-backend-file,id=mem,size=%s,mem-path=/dev/hugepages,share=on" %(kwargs["-m"]))
+            "memory-backend-file,id=mem,size=%s,mem-path=/dev/hugepages,share=on"
+            %(kwargs["-m"]))
         kwargs["-numa"] = kwargs.get("-numa", "node,memdev=mem")
         kwargs["-mem-prealloc"] = kwargs.get("-mem-prealloc", "")
 
@@ -267,6 +257,7 @@ class OvsHost(linux.LinuxDevice):
 
             if "vhost-user" in p["-netdev"]:
                 # type: vhostuserclient
+                # Parse the parameter for -chardev/-netdev/-device
                 chardev = {}
                 for attribute in p["-chardev"].split(","):
                     if ("=" in attribute):
